@@ -10,19 +10,23 @@ test_that("nhd_plus_get fails well", {
                "100 is not a valid vpu")
 })
 
-#' @importFrom RCurl url.exists
+#' @importFrom crul ok
+#' @importFrom fauxpas http200
+
 test_that("remote urls are constructed correctly", {
   skip_on_cran()
   skip_on_travis()
 
   expect_true(
-    RCurl::url.exists(
-      nhdR:::get_plus_remotepath(4, component = "NHDSnapshot"))
+    crul::ok(
+      nhdR:::get_plus_remotepath(4, component = "NHDSnapshot")
+      )
     )
 
   expect_true(
-    RCurl::url.exists(
-      nhdR:::get_plus_remotepath("National", component = "V1_To_V2_Crosswalk"))
+    crul::ok(
+      nhdR:::get_plus_remotepath("National", component = "V1_To_V2_Crosswalk"),
+      status = 200L)
     )
 
 
