@@ -33,3 +33,20 @@ test_that("nhd_plus_query fails well", {
                                 buffer_dist = 0.1),
                "nhd_plus_query only accepts a single lon-lat pair.")
 })
+
+
+test_that("nhd_plus_query handles mismatched column names.", {
+  skip_on_cran()
+  skip_on_travis()
+
+  # https://github.com/jsta/nhdR/issues/57
+  box <- sf::st_bbox(c(xmin = -105.93003, xmax = -104.91784,
+                   ymin = 40.41176, ymax = 41.21014),
+                crs = st_crs(4326)) %>%
+    sf::st_as_sfc()
+  poudre_flow <- nhd_plus_query(poly = box,
+                                dsn = c('NHDFlowLine'),
+                                quiet = TRUE)
+
+  expect_s3_class(poudre_flow$sp$NHDFlowLine, "sf")
+})
