@@ -17,6 +17,9 @@ test_that("find_vpu works with numeric vpus", {
 })
 
 test_that("toUTM works", {
+  skip_on_cran()
+  skip_on_travis()
+
   data(gull)
   data(mendota)
   data(sunapee)
@@ -30,14 +33,14 @@ test_that("toUTM works", {
     st_transform(gull$sp$NHDWaterbody, 4326),
     st_transform(sunapee$sp$NHDWaterbody, 4326))
 
-  expect_equal(get_utm_zone(st_crs(toUTM(gull$sp$NHDWaterbody))),
+  expect_true(get_utm_zone(st_crs(toUTM(gull$sp$NHDWaterbody))) ==
                "16")
 
   big_combined <- rbind(
     st_transform(sunapee$sp$NHDWaterbody, 4326),
     st_transform(gull$sp$NHDWaterbody, 4326))
 
-  expect_equal(st_crs(toUTM(sunapee$sp$NHDWaterbody)),
+  expect_true(st_crs(toUTM(sunapee$sp$NHDWaterbody)) ==
                st_crs(toUTM(big_combined)))
 
 })
